Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(322)

Unified Diff: content/renderer/categorized_worker_pool.h

Issue 2021323002: content: Rename RasterWorkerPool -> CategorizedWorkerPool. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@task_graph_runner_test_2
Patch Set: rebase Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/content_tests.gypi ('k') | content/renderer/categorized_worker_pool.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/renderer/categorized_worker_pool.h
diff --git a/content/renderer/raster_worker_pool.h b/content/renderer/categorized_worker_pool.h
similarity index 83%
rename from content/renderer/raster_worker_pool.h
rename to content/renderer/categorized_worker_pool.h
index 10c312be68b1b2de4ab2e1102faa69b5103d987b..2f75f2183f24d0c145e55697f53c86470f371837 100644
--- a/content/renderer/raster_worker_pool.h
+++ b/content/renderer/categorized_worker_pool.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CONTENT_RENDERER_RASTER_WORKER_POOL_H_
-#define CONTENT_RENDERER_RASTER_WORKER_POOL_H_
+#ifndef CONTENT_RENDERER_CATEGORIZED_WORKER_POOL_H_
+#define CONTENT_RENDERER_CATEGORIZED_WORKER_POOL_H_
#include <memory>
@@ -21,18 +21,18 @@
namespace content {
-// A pool of threads used to run raster work.
-// Work can be scheduled on the threads using different interfaces.
-// The pool itself implements TaskRunner interface and tasks posted via that
-// interface might run in parallel.
-// CreateSequencedTaskRunner creates a sequenced task runner that might run in
-// parallel with other instances of sequenced task runners.
-// It's also possible to get the underlying TaskGraphRunner to schedule a graph
-// of tasks with their dependencies.
-class CONTENT_EXPORT RasterWorkerPool : public base::TaskRunner,
- public cc::TaskGraphRunner {
+// A pool of threads used to run categorized work. The work can be scheduled on
+// the threads using different interfaces.
+// 1. The pool itself implements TaskRunner interface and tasks posted via that
+// interface might run in parallel.
+// 2. The pool also implements TaskGraphRunner interface which allows to
+// schedule a graph of tasks with their dependencies.
+// 3. CreateSequencedTaskRunner() creates a sequenced task runner that might run
+// in parallel with other instances of sequenced task runners.
+class CONTENT_EXPORT CategorizedWorkerPool : public base::TaskRunner,
+ public cc::TaskGraphRunner {
public:
- RasterWorkerPool();
+ CategorizedWorkerPool();
// Overridden from base::TaskRunner:
bool PostDelayedTask(const tracked_objects::Location& from_here,
@@ -70,11 +70,11 @@ class CONTENT_EXPORT RasterWorkerPool : public base::TaskRunner,
scoped_refptr<base::SequencedTaskRunner> CreateSequencedTaskRunner();
protected:
- ~RasterWorkerPool() override;
+ ~CategorizedWorkerPool() override;
private:
- class RasterWorkerPoolSequencedTaskRunner;
- friend class RasterWorkerPoolSequencedTaskRunner;
+ class CategorizedWorkerPoolSequencedTaskRunner;
+ friend class CategorizedWorkerPoolSequencedTaskRunner;
// Simple Task for the TaskGraphRunner that wraps a closure.
// This class is used to schedule TaskRunner tasks on the
@@ -145,4 +145,4 @@ class CONTENT_EXPORT RasterWorkerPool : public base::TaskRunner,
} // namespace content
-#endif // CONTENT_RENDERER_RASTER_WORKER_POOL_H_
+#endif // CONTENT_RENDERER_CATEGORIZED_WORKER_POOL_H_
« no previous file with comments | « content/content_tests.gypi ('k') | content/renderer/categorized_worker_pool.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698